==> react-native-animmated-image-resizer-1.0.1-beta.1.tgz: package/android/src/main/java/com/imageresizer/BitmapUtility.java <==
package com.imageresizer;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;

import android.content.Context;
import android.util.Log;

import com.bumptech.glide.Glide;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.concurrent.ExecutionException;
import com.bumptech.glide.load.engine.DiskCacheStrategy;

public class BitmapUtility {
    private static String TAG = BitmapUtility.class.getSimpleName();
    public Context context;

    public BitmapUtility(Context context) {

        this.context = context;
    }
    
    public Bitmap resizeGlide(Bitmap bitmap) throws ExecutionException, InterruptedException {
        return Glide.with(context)
                .asBitmap()
                .skipMemoryCache(true)
                .diskCacheStrategy(DiskCacheStrategy.NONE)
                .load(bitmap)
                .override(512, 512)
                .centerInside()
                .submit().get();
    }


    private static Bitmap fitCenter(Bitmap image, int maxWidth, int maxHeight) {
        if (maxHeight > 0 && maxWidth > 0) {
            int width = image.getWidth();
            int height = image.getHeight();
            float ratioBitmap = (float) width / (float) height;
            float ratioMax = (float) maxWidth / (float) maxHeight;

            int finalWidth = maxWidth;
            int finalHeight = maxHeight;
            if (ratioMax > ratioBitmap) {
                finalWidth = (int) ((float)maxHeight * ratioBitmap);
            } else {
                finalHeight = (int) ((float)maxWidth / ratioBitmap);
            }
            image = Bitmap.createScaledBitmap(image, finalWidth, finalHeight, true);
            return image;
        } else {
            return image;
        }
    }
    //    public static Bitmap fitCenter(Bitmap imageToScale, int destinationWidth, int destinationHeight) {
//        Log.v(TAG,"FIT CNETER");
//        if (destinationHeight > 0 && destinationWidth > 0 && imageToScale != null) {
//
//            int width = imageToScale.getWidth();
//            int height = imageToScale.getHeight();
//
//            // Calculate the max changing amount and decide which dimension to use
//            float widthRatio = (float) destinationWidth / (float) width;
//            float heightRatio = (float) destinationHeight / (float) height;
//
//            // Use the ratio that will fit the image into the desired sizes
//            float minRatio = Math.min(widthRatio, heightRatio);
//
//            int finalWidth = (int) Math.floor(width * minRatio);
//            int finalHeight = (int) Math.floor(height * minRatio);
//
//            // Scale given bitmap to fit into the desired area
//            imageToScale = Bitmap.createScaledBitmap(imageToScale, finalWidth, finalHeight, true);
//
//            // Create a bitmap with desired sizes
//            Bitmap scaledImage = Bitmap.createBitmap(destinationWidth, destinationHeight, Bitmap.Config.ARGB_8888);
//
//            Canvas canvas = new Canvas(scaledImage);
//            // Draw background color
//            Paint paint = new Paint();
//            paint.setColor(Color.TRANSPARENT); // if transparent then encoder must read ALPHA
//            paint.setStyle(Paint.Style.FILL);
//            canvas.drawRect(0, 0, canvas.getWidth(), canvas.getHeight(), paint);
//
//            // Calculate the ratios and decide which part will have empty areas (width or height)
//            float ratioBitmap = (float) finalWidth / (float) finalHeight;
//            float destinationRatio = (float) destinationWidth / (float) destinationHeight;
//            float left = ratioBitmap >= destinationRatio ? 0 : (float) (destinationWidth - finalWidth) / 2;
//            float top = ratioBitmap < destinationRatio ? 0 : (float) (destinationHeight - finalHeight) / 2;
//            canvas.drawBitmap(imageToScale, left, top, null);
//
//            return scaledImage;
//        } else {
//            return imageToScale;
//        }
//    }

    public static Bitmap crop(Bitmap img, int width, int height) {
        Log.v(TAG,"crop");

        int imgWidth = img.getWidth();
        int imgHeight = img.getHeight();

        float scale = Math.max(width / (float) imgWidth, height / (float) imgHeight);

        int scaledWidth = (int) (imgWidth * scale);
        int scaledHeight = (int) (imgHeight * scale);

        Bitmap scaledImg = Bitmap.createScaledBitmap(img, scaledWidth, scaledHeight, true);

        int cropX = (scaledWidth - width) / 2;
        int cropY = (scaledHeight - height) / 2;

        return Bitmap.createBitmap(scaledImg, cropX, cropY, width, height);

    }
    public static Bitmap stretch(Bitmap img, int width, int height) {
        Log.v(TAG,"stretch");

        return Bitmap.createScaledBitmap(img, width, height, false);

    }


    public static Bitmap resizeBitmap(Bitmap bitmap, StaticOptions options) {

        ScaleMode scaleMode = ScaleMode.fromString(options.scaleMode);
        Log.v(TAG,"Mode os "+scaleMode.getMode());

        return applyScaling(bitmap, scaleMode, options.width, options.height);

    }

    private static Bitmap applyScaling(Bitmap bitmap, ScaleMode crop, int width, int height) {
        switch (crop) {
            case FIT_CENTER:
                return fitCenter(bitmap, width, height);
            case CROP:
                return crop(bitmap, width, height);
            case STRETCH:
                return stretch(bitmap, width, height);
            default:
                return fitCenter(bitmap, width, height);
        }
    }
    private static Bitmap.CompressFormat getCompressFormat(String format) {
        switch (format.toLowerCase()) {
            case "jpeg":
            case "jpg":
                return Bitmap.CompressFormat.JPEG;
            case "png":
                return Bitmap.CompressFormat.PNG;
            case "webp":
                return Bitmap.CompressFormat.WEBP;
            default:
                // Default to JPEG for incorrect format
                return Bitmap.CompressFormat.JPEG;
        }
    }
    public static File saveBitmapToFile(Bitmap newBitmap, String format, int quality) throws FileNotFoundException {
        FileUtility util = new FileUtility();
        File file = util.createOutputFile(format);

        Bitmap.CompressFormat validFormat = getCompressFormat(format);

        try(FileOutputStream fos = new FileOutputStream(file)){
            newBitmap.compress(validFormat, quality, fos);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }

        return file;
    }
}

==> react-native-animmated-image-resizer-1.0.6-beta.1.tgz: package/android/src/main/java/com/imageresizer/BitmapUtility.java <==
package com.imageresizer;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;

import android.content.Context;
import android.util.Log;

import com.bumptech.glide.Glide;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.concurrent.ExecutionException;
import com.bumptech.glide.load.engine.DiskCacheStrategy;

public class BitmapUtility {
    private static String TAG = BitmapUtility.class.getSimpleName();
    public Context context;

    public BitmapUtility(Context context) {

        this.context = context;
    }
    
    public Bitmap resizeGlide(Bitmap bitmap) throws ExecutionException, InterruptedException {
        return Glide.with(context)
                .asBitmap()
                .skipMemoryCache(true)
                .diskCacheStrategy(DiskCacheStrategy.NONE)
                .load(bitmap)
                .override(512, 512)
                .centerInside()
                .submit().get();
    }


    private static Bitmap fitCenter2(Bitmap image, int maxWidth, int maxHeight) {
        if (maxHeight > 0 && maxWidth > 0) {
            int width = image.getWidth();
            int height = image.getHeight();
            float ratioBitmap = (float) width / (float) height;
            float ratioMax = (float) maxWidth / (float) maxHeight;

            int finalWidth = maxWidth;
            int finalHeight = maxHeight;
            if (ratioMax > ratioBitmap) {
                finalWidth = (int) ((float)maxHeight * ratioBitmap);
            } else {
                finalHeight = (int) ((float)maxWidth / ratioBitmap);
            }
            image = Bitmap.createScaledBitmap(image, finalWidth, finalHeight, true);
            return image;
        } else {
            return image;
        }
    }
    public static Bitmap fitCenter(Bitmap imageToScale, int destinationWidth, int destinationHeight) {
        Log.v(TAG,"FIT CNETER");
        if (destinationHeight > 0 && destinationWidth > 0 && imageToScale != null) {

            int width = imageToScale.getWidth();
            int height = imageToScale.getHeight();

            // Calculate the max changing amount and decide which dimension to use
            float widthRatio = (float) destinationWidth / (float) width;
            float heightRatio = (float) destinationHeight / (float) height;

            // Use the ratio that will fit the image into the desired sizes
            float minRatio = Math.min(widthRatio, heightRatio);

            int finalWidth = (int) Math.floor(width * minRatio);
            int finalHeight = (int) Math.floor(height * minRatio);

            // Scale given bitmap to fit into the desired area
            imageToScale = Bitmap.createScaledBitmap(imageToScale, finalWidth, finalHeight, true);

            // Create a bitmap with desired sizes
            Bitmap scaledImage = Bitmap.createBitmap(destinationWidth, destinationHeight, Bitmap.Config.ARGB_8888);

            Canvas canvas = new Canvas(scaledImage);
            // Draw background color
            Paint paint = new Paint();
            paint.setColor(Color.TRANSPARENT); // if transparent then encoder must read ALPHA
            paint.setStyle(Paint.Style.FILL);
            canvas.drawRect(0, 0, canvas.getWidth(), canvas.getHeight(), paint);

            // Calculate the ratios and decide which part will have empty areas (width or height)
            float ratioBitmap = (float) finalWidth / (float) finalHeight;
            float destinationRatio = (float) destinationWidth / (float) destinationHeight;
            float left = ratioBitmap >= destinationRatio ? 0 : (float) (destinationWidth - finalWidth) / 2;
            float top = ratioBitmap < destinationRatio ? 0 : (float) (destinationHeight - finalHeight) / 2;
            canvas.drawBitmap(imageToScale, left, top, null);

            return scaledImage;
        } else {
            return imageToScale;
        }
    }

    public static Bitmap crop(Bitmap img, int width, int height) {
        Log.v(TAG,"crop");

        int imgWidth = img.getWidth();
        int imgHeight = img.getHeight();

        float scale = Math.max(width / (float) imgWidth, height / (float) imgHeight);

        int scaledWidth = (int) (imgWidth * scale);
        int scaledHeight = (int) (imgHeight * scale);

        Bitmap scaledImg = Bitmap.createScaledBitmap(img, scaledWidth, scaledHeight, true);

        int cropX = (scaledWidth - width) / 2;
        int cropY = (scaledHeight - height) / 2;

        return Bitmap.createBitmap(scaledImg, cropX, cropY, width, height);

    }
    public static Bitmap stretch(Bitmap img, int width, int height) {
        Log.v(TAG,"stretch");

        return Bitmap.createScaledBitmap(img, width, height, false);

    }


    public static Bitmap resizeBitmap(Bitmap bitmap, StaticOptions options) {

        ScaleMode scaleMode = ScaleMode.fromString(options.scaleMode);
        Log.v(TAG,"Mode os "+scaleMode.getMode());

        return applyScaling(bitmap, scaleMode, options.width, options.height);

    }

    private static Bitmap applyScaling(Bitmap bitmap, ScaleMode crop, int width, int height) {
        switch (crop) {
            case FIT_CENTER:
                return fitCenter(bitmap, width, height);
            case CROP:
                return crop(bitmap, width, height);
            case STRETCH:
                return stretch(bitmap, width, height);
            default:
                return fitCenter(bitmap, width, height);
        }
    }
    private static Bitmap.CompressFormat getCompressFormat(String format) {
        switch (format.toLowerCase()) {
            case "jpeg":
            case "jpg":
                return Bitmap.CompressFormat.JPEG;
            case "png":
                return Bitmap.CompressFormat.PNG;
            case "webp":
                return Bitmap.CompressFormat.WEBP;
            default:
                // Default to JPEG for incorrect format
                return Bitmap.CompressFormat.JPEG;
        }
    }
    public static File saveBitmapToFile(Bitmap newBitmap, String format, int quality) throws FileNotFoundException {
        FileUtility util = new FileUtility();
        File file = util.createOutputFile(format);

        Bitmap.CompressFormat validFormat = getCompressFormat(format);

        try(FileOutputStream fos = new FileOutputStream(file)){
            newBitmap.compress(validFormat, quality, fos);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }

        return file;
    }
}
